﻿using System;
using System.Collections.Generic;
using Microsoft.EntityFrameworkCore;

namespace IposiGospodDemo.Context;

public partial class User3Context : DbContext
{
    public User3Context()
    {
    }

    public User3Context(DbContextOptions<User3Context> options)
        : base(options)
    {
    }

    public virtual DbSet<Charity> Charities { get; set; }

    public virtual DbSet<Country> Countries { get; set; }

    public virtual DbSet<Event> Events { get; set; }

    public virtual DbSet<EventType> EventTypes { get; set; }

    public virtual DbSet<Gender> Genders { get; set; }

    public virtual DbSet<Marathon> Marathons { get; set; }

    public virtual DbSet<Position> Positions { get; set; }

    public virtual DbSet<RaceKitOption> RaceKitOptions { get; set; }

    public virtual DbSet<Registration> Registrations { get; set; }

    public virtual DbSet<RegistrationEvent> RegistrationEvents { get; set; }

    public virtual DbSet<RegistrationStatus> RegistrationStatuses { get; set; }

    public virtual DbSet<Role> Roles { get; set; }

    public virtual DbSet<Runner> Runners { get; set; }

    public virtual DbSet<Sponsorship> Sponsorships { get; set; }

    public virtual DbSet<Staff> Staff { get; set; }

    public virtual DbSet<Timesheet> Timesheets { get; set; }

    public virtual DbSet<User> Users { get; set; }

    public virtual DbSet<Volunteer> Volunteers { get; set; }

    protected override void OnConfiguring(DbContextOptionsBuilder optionsBuilder)
#warning To protect potentially sensitive information in your connection string, you should move it out of source code. You can avoid scaffolding the connection string by using the Name= syntax to read it from configuration - see https://go.microsoft.com/fwlink/?linkid=2131148. For more guidance on storing connection strings, see https://go.microsoft.com/fwlink/?LinkId=723263.
        => optionsBuilder.UseNpgsql("Host=45.67.56.214;Port=5454;Database=user3;Username=user3;password=VOTfZ8PQ");

    protected override void OnModelCreating(ModelBuilder modelBuilder)
    {
        modelBuilder.Entity<Charity>(entity =>
        {
            entity.HasKey(e => e.CharityId).HasName("Charity_pkey");

            entity.ToTable("Charity", "public3");

            entity.Property(e => e.CharityDescription).HasMaxLength(2000);
            entity.Property(e => e.CharityLogo).HasMaxLength(50);
            entity.Property(e => e.CharityName).HasMaxLength(100);
        });

        modelBuilder.Entity<Country>(entity =>
        {
            entity.HasKey(e => e.CountryCode).HasName("Country_pkey");

            entity.ToTable("Country", "public3");

            entity.Property(e => e.CountryCode)
                .HasMaxLength(3)
                .IsFixedLength();
            entity.Property(e => e.CountryFlag).HasMaxLength(100);
            entity.Property(e => e.CountryName).HasMaxLength(100);
        });

        modelBuilder.Entity<Event>(entity =>
        {
            entity.HasKey(e => e.EventId).HasName("Event_pkey");

            entity.ToTable("Event", "public3");

            entity.Property(e => e.EventId)
                .HasMaxLength(6)
                .IsFixedLength();
            entity.Property(e => e.Cost).HasPrecision(10, 2);
            entity.Property(e => e.EventName).HasMaxLength(50);
            entity.Property(e => e.EventTypeId)
                .HasMaxLength(2)
                .IsFixedLength();
            entity.Property(e => e.StartDateTime).HasColumnType("timestamp without time zone");

            entity.HasOne(d => d.EventType).WithMany(p => p.Events)
                .HasForeignKey(d => d.EventTypeId)
                .OnDelete(DeleteBehavior.ClientSetNull)
                .HasConstraintName("Event_EventTypeId_fkey");

            entity.HasOne(d => d.Marathon).WithMany(p => p.Events)
                .HasForeignKey(d => d.MarathonId)
                .OnDelete(DeleteBehavior.ClientSetNull)
                .HasConstraintName("Event_MarathonId_fkey");
        });

        modelBuilder.Entity<EventType>(entity =>
        {
            entity.HasKey(e => e.EventTypeId).HasName("EventType_pkey");

            entity.ToTable("EventType", "public3");

            entity.Property(e => e.EventTypeId)
                .HasMaxLength(2)
                .IsFixedLength();
            entity.Property(e => e.EventTypeName).HasMaxLength(50);
        });

        modelBuilder.Entity<Gender>(entity =>
        {
            entity.HasKey(e => e.Gender1).HasName("Gender_pkey");

            entity.ToTable("Gender", "public3");

            entity.Property(e => e.Gender1)
                .HasMaxLength(10)
                .HasColumnName("Gender");
        });

        modelBuilder.Entity<Marathon>(entity =>
        {
            entity.HasKey(e => e.MarathonId).HasName("Marathon_pkey");

            entity.ToTable("Marathon", "public3");

            entity.Property(e => e.MarathonId).ValueGeneratedNever();
            entity.Property(e => e.CityName).HasMaxLength(80);
            entity.Property(e => e.CountryCode)
                .HasMaxLength(3)
                .IsFixedLength();
            entity.Property(e => e.MarathonName).HasMaxLength(80);

            entity.HasOne(d => d.CountryCodeNavigation).WithMany(p => p.Marathons)
                .HasForeignKey(d => d.CountryCode)
                .OnDelete(DeleteBehavior.ClientSetNull)
                .HasConstraintName("Marathon_CountryCode_fkey");
        });

        modelBuilder.Entity<Position>(entity =>
        {
            entity.HasKey(e => e.PositionId).HasName("Position_pkey");

            entity.ToTable("Position", "public3");

            entity.Property(e => e.PayRate).HasPrecision(10, 2);
            entity.Property(e => e.PositionDescription).HasMaxLength(255);
            entity.Property(e => e.PositionName).HasMaxLength(100);
        });

        modelBuilder.Entity<RaceKitOption>(entity =>
        {
            entity.HasKey(e => e.RaceKitOptionId).HasName("RaceKitOption_pkey");

            entity.ToTable("RaceKitOption", "public3");

            entity.Property(e => e.RaceKitOptionId)
                .HasMaxLength(1)
                .ValueGeneratedNever();
            entity.Property(e => e.Cost).HasPrecision(10, 2);
            entity.Property(e => e.RaceKitOption1)
                .HasMaxLength(80)
                .HasColumnName("RaceKitOption");
        });

        modelBuilder.Entity<Registration>(entity =>
        {
            entity.HasKey(e => e.RegistrationId).HasName("Registration_pkey");

            entity.ToTable("Registration", "public3");

            entity.Property(e => e.Cost).HasPrecision(10, 2);
            entity.Property(e => e.RaceKitOptionId).HasMaxLength(1);
            entity.Property(e => e.RegistrationDateTime).HasColumnType("timestamp without time zone");
            entity.Property(e => e.SponsorshipTarget).HasPrecision(10, 2);

            entity.HasOne(d => d.Charity).WithMany(p => p.Registrations)
                .HasForeignKey(d => d.CharityId)
                .OnDelete(DeleteBehavior.ClientSetNull)
                .HasConstraintName("Registration_CharityId_fkey");

            entity.HasOne(d => d.RaceKitOption).WithMany(p => p.Registrations)
                .HasForeignKey(d => d.RaceKitOptionId)
                .OnDelete(DeleteBehavior.ClientSetNull)
                .HasConstraintName("Registration_RaceKitOptionId_fkey");

            entity.HasOne(d => d.RegistrationStatus).WithMany(p => p.Registrations)
                .HasForeignKey(d => d.RegistrationStatusId)
                .OnDelete(DeleteBehavior.ClientSetNull)
                .HasConstraintName("Registration_RegistrationStatusId_fkey");

            entity.HasOne(d => d.Runner).WithMany(p => p.Registrations)
                .HasForeignKey(d => d.RunnerId)
                .OnDelete(DeleteBehavior.ClientSetNull)
                .HasConstraintName("Registration_RunnerId_fkey");
        });

        modelBuilder.Entity<RegistrationEvent>(entity =>
        {
            entity.HasKey(e => e.RegistrationEventId).HasName("RegistrationEvent_pkey");

            entity.ToTable("RegistrationEvent", "public3");

            entity.Property(e => e.EventId)
                .HasMaxLength(6)
                .IsFixedLength();

            entity.HasOne(d => d.Event).WithMany(p => p.RegistrationEvents)
                .HasForeignKey(d => d.EventId)
                .OnDelete(DeleteBehavior.ClientSetNull)
                .HasConstraintName("RegistrationEvent_EventId_fkey");

            entity.HasOne(d => d.Registration).WithMany(p => p.RegistrationEvents)
                .HasForeignKey(d => d.RegistrationId)
                .OnDelete(DeleteBehavior.ClientSetNull)
                .HasConstraintName("RegistrationEvent_RegistrationId_fkey");
        });

        modelBuilder.Entity<RegistrationStatus>(entity =>
        {
            entity.HasKey(e => e.RegistrationStatusId).HasName("RegistrationStatus_pkey");

            entity.ToTable("RegistrationStatus", "public3");

            entity.Property(e => e.RegistrationStatusId).ValueGeneratedNever();
            entity.Property(e => e.RegistrationStatus1)
                .HasMaxLength(80)
                .HasColumnName("RegistrationStatus");
        });

        modelBuilder.Entity<Role>(entity =>
        {
            entity.HasKey(e => e.RoleId).HasName("Role_pkey");

            entity.ToTable("Role", "public3");

            entity.Property(e => e.RoleId)
                .HasMaxLength(1)
                .ValueGeneratedNever();
            entity.Property(e => e.RoleName).HasMaxLength(50);
        });

        modelBuilder.Entity<Runner>(entity =>
        {
            entity.HasKey(e => e.RunnerId).HasName("Runner_pkey");

            entity.ToTable("Runner", "public3");

            entity.Property(e => e.CountryCode)
                .HasMaxLength(3)
                .IsFixedLength();
            entity.Property(e => e.DateOfBirth).HasColumnType("timestamp without time zone");
            entity.Property(e => e.Email).HasMaxLength(100);
            entity.Property(e => e.Gender).HasMaxLength(10);

            entity.HasOne(d => d.CountryCodeNavigation).WithMany(p => p.Runners)
                .HasForeignKey(d => d.CountryCode)
                .OnDelete(DeleteBehavior.ClientSetNull)
                .HasConstraintName("Runner_CountryCode_fkey");

            entity.HasOne(d => d.EmailNavigation).WithMany(p => p.Runners)
                .HasForeignKey(d => d.Email)
                .OnDelete(DeleteBehavior.ClientSetNull)
                .HasConstraintName("Runner_Email_fkey");

            entity.HasOne(d => d.GenderNavigation).WithMany(p => p.Runners)
                .HasForeignKey(d => d.Gender)
                .OnDelete(DeleteBehavior.ClientSetNull)
                .HasConstraintName("Runner_Gender_fkey");
        });

        modelBuilder.Entity<Sponsorship>(entity =>
        {
            entity.HasKey(e => e.SponsorshipId).HasName("Sponsorship_pkey");

            entity.ToTable("Sponsorship", "public3");

            entity.Property(e => e.Amount).HasPrecision(10, 2);
            entity.Property(e => e.SponsorName).HasMaxLength(150);

            entity.HasOne(d => d.Registration).WithMany(p => p.Sponsorships)
                .HasForeignKey(d => d.RegistrationId)
                .OnDelete(DeleteBehavior.ClientSetNull)
                .HasConstraintName("Sponsorship_RegistrationId_fkey");
        });

        modelBuilder.Entity<Staff>(entity =>
        {
            entity.HasKey(e => e.StaffId).HasName("Staff_pkey");

            entity.ToTable("Staff", "public3");

            entity.Property(e => e.Email).HasMaxLength(100);
            entity.Property(e => e.FirstName).HasMaxLength(100);
            entity.Property(e => e.Gender).HasMaxLength(1);
            entity.Property(e => e.LastName).HasMaxLength(100);

            entity.HasOne(d => d.Position).WithMany(p => p.Staff)
                .HasForeignKey(d => d.PositionId)
                .OnDelete(DeleteBehavior.ClientSetNull)
                .HasConstraintName("Staff_PositionId_fkey");
        });

        modelBuilder.Entity<Timesheet>(entity =>
        {
            entity.HasKey(e => e.TimesheetId).HasName("Timesheet_pkey");

            entity.ToTable("Timesheet", "public3");

            entity.Property(e => e.EndDateTime).HasColumnType("timestamp without time zone");
            entity.Property(e => e.PayAmount).HasPrecision(10, 2);
            entity.Property(e => e.StartDateTime).HasColumnType("timestamp without time zone");

            entity.HasOne(d => d.Staff).WithMany(p => p.Timesheets)
                .HasForeignKey(d => d.StaffId)
                .OnDelete(DeleteBehavior.ClientSetNull)
                .HasConstraintName("Timesheet_StaffId_fkey");
        });

        modelBuilder.Entity<User>(entity =>
        {
            entity.HasKey(e => e.Email).HasName("User_pkey");

            entity.ToTable("User", "public3");

            entity.Property(e => e.Email).HasMaxLength(100);
            entity.Property(e => e.FirstName).HasMaxLength(80);
            entity.Property(e => e.LastName).HasMaxLength(80);
            entity.Property(e => e.Password).HasMaxLength(100);
            entity.Property(e => e.RoleId).HasMaxLength(1);

            entity.HasOne(d => d.Role).WithMany(p => p.Users)
                .HasForeignKey(d => d.RoleId)
                .OnDelete(DeleteBehavior.ClientSetNull)
                .HasConstraintName("User_RoleId_fkey");
        });

        modelBuilder.Entity<Volunteer>(entity =>
        {
            entity.HasKey(e => e.VolunteerId).HasName("Volunteer_pkey");

            entity.ToTable("Volunteer", "public3");

            entity.Property(e => e.CountryCode)
                .HasMaxLength(3)
                .IsFixedLength();
            entity.Property(e => e.FirstName).HasMaxLength(80);
            entity.Property(e => e.Gender).HasMaxLength(10);
            entity.Property(e => e.LastName).HasMaxLength(80);

            entity.HasOne(d => d.CountryCodeNavigation).WithMany(p => p.Volunteers)
                .HasForeignKey(d => d.CountryCode)
                .OnDelete(DeleteBehavior.ClientSetNull)
                .HasConstraintName("Volunteer_CountryCode_fkey");

            entity.HasOne(d => d.GenderNavigation).WithMany(p => p.Volunteers)
                .HasForeignKey(d => d.Gender)
                .OnDelete(DeleteBehavior.ClientSetNull)
                .HasConstraintName("Volunteer_Gender_fkey");
        });

        OnModelCreatingPartial(modelBuilder);
    }

    partial void OnModelCreatingPartial(ModelBuilder modelBuilder);
}
