using System;
using System.Collections.Generic;
using System.Linq;
using System.Reactive;
using IposiGospodDemo.Context;
using IposiGospodDemo.Helpers;
using IposiGospodDemo.Views;
using Microsoft.EntityFrameworkCore;
using ReactiveUI;

namespace IposiGospodDemo.ViewModels;

public class SponsorARunnerWindowViewModel : ViewModelBase
{
    public List<Runner> Runners { get; set; }

    private Runner _selectedRunner;

    public Runner SelectedRunner
    {
        get => _selectedRunner;
        set
        { 
            if (_selectedRunner != value)
            {
                _selectedRunner = value;
                this.RaisePropertyChanged();
            }
            SelectedCharity = value?.Registrations?.FirstOrDefault()?.Charity;
        }
    }

    private Charity _selectedCharity;

    public Charity SelectedCharity
    {
        get => _selectedCharity;
        set => this.RaiseAndSetIfChanged(ref _selectedCharity, value);
    }

    private decimal _sum = 50;

    public decimal Sum
    {
        get => _sum;
        set => this.RaiseAndSetIfChanged(ref _sum, value);
    }
    
    private string _sponsorName;
    public string SponsorName
    {
        get => _sponsorName;
        set => this.RaiseAndSetIfChanged(ref _sponsorName, value);
    }

    private string _cardOwner;
    public string CardOwner
    {
        get => _cardOwner;
        set => this.RaiseAndSetIfChanged(ref _cardOwner, value);
    }

    private string _cardNumber;
    public string CardNumber
    {
        get => _cardNumber;
        set => this.RaiseAndSetIfChanged(ref _cardNumber, value);
    }

    private string _month;
    public string Month
    {
        get => _month;
        set => this.RaiseAndSetIfChanged(ref _month, value);
    }

    private string _year;
    public string Year
    {
        get => _year;
        set => this.RaiseAndSetIfChanged(ref _year, value);
    }

    private string _cvc;
    public string Cvc
    {
        get => _cvc;
        set => this.RaiseAndSetIfChanged(ref _cvc, value);
    }


    public ReactiveCommand<Unit, Unit> IncreaseSumCommand { get; }
    public ReactiveCommand<Unit, Unit> DecreaseSumCommand { get; }
    
    public ReactiveCommand<Unit, Unit> OpenCharityInfoWindow { get; }
    
    public SponsorARunnerWindowViewModel()
    {
        Runners = DbHelper.Database.Runners
            .Include(r => r.CountryCodeNavigation)
            .Include(r => r.EmailNavigation)
            .Include(r => r.Registrations)
            .ThenInclude(reg => reg.Charity)
            .ToList();
        SelectedRunner = Runners[0];

        IncreaseSumCommand = ReactiveCommand.Create(IncreaseSum);
        DecreaseSumCommand = ReactiveCommand.Create(DecreaseSum);
        OpenCharityInfoWindow = ReactiveCommand.Create(OpenCharityInfoWindowFunc);
    }

    void DecreaseSum()
    {
        if (Sum < 11)
            Sum = 1;
        else Sum -= 10;
    }

    void IncreaseSum()
    {
        Sum += 10;
    }

    void OpenCharityInfoWindowFunc()
    {
        new CharityInfoWindow(SelectedCharity).Show();
    }
}