using System;
using System.Linq;
using Avalonia;
using Avalonia.Controls;
using Avalonia.Interactivity;
using Avalonia.Markup.Xaml;
using IposiGospodDemo.Context;
using IposiGospodDemo.Helpers;
using IposiGospodDemo.ViewModels;

namespace IposiGospodDemo.Views;

public partial class SponsorARunnerWindow : Window
{
    private SponsorARunnerWindowViewModel? _viewModel;
    
    public SponsorARunnerWindow()
    {
        InitializeComponent();
        DataContext = new SponsorARunnerWindowViewModel();
        Loaded += OnLoaded;
    }

    private void OnLoaded(object? sender, Avalonia.Interactivity.RoutedEventArgs e)
    {
        _viewModel = (DataContext as SponsorARunnerWindowViewModel)!;
    }
    
    
    private void GoBack_OnClick(object? sender, RoutedEventArgs e)
    {
        new MainWindow().Show();
        Close();
    }

    private void Pay_OnClick(object? sender, RoutedEventArgs e)
    {
        string? SponsorName = _viewModel?.SponsorName;
        string? CardOwner = _viewModel?.CardOwner;
        string? CardNumber = _viewModel?.CardNumber;
        string? Month = _viewModel?.Month;
        string? Year = _viewModel?.Year;
        string? Cvc = _viewModel?.Cvc;

        if (_viewModel.SelectedRunner == null)
        {
            Console.WriteLine("Не выбран бегун");
            return;
        }
        
        if (string.IsNullOrWhiteSpace(SponsorName) ||
            string.IsNullOrWhiteSpace(CardOwner) ||
            string.IsNullOrWhiteSpace(CardNumber) ||
            string.IsNullOrWhiteSpace(Month) ||
            string.IsNullOrWhiteSpace(Year) ||
            string.IsNullOrWhiteSpace(Cvc))
        {
            Console.WriteLine("Ошибка: Заполните все поля!");
            return;
        }
        
        if (!long.TryParse(CardNumber.Replace(" ", ""), out _) || CardNumber.Length < 16)
        {
            Console.WriteLine("Ошибка: Некорректный номер карты!");
            return;
        }
        
        if (!int.TryParse(Month, out var month) || month < 1 || month > 12)
        {
            Console.WriteLine("Ошибка: Некорректный месяц!");
            return;
        }
        
        if (!int.TryParse(Year, out var year))
        {
            Console.WriteLine("Ошибка: Некорректный год!");
            return;
        }
        
        if (!int.TryParse(Cvc, out _) || Cvc.Length != 3)
        {
            Console.WriteLine("Ошибка: Некорректный CVC!");
            return;
        }

        Sponsorship newSponsorship = new Sponsorship();
        newSponsorship.SponsorName = SponsorName;
        newSponsorship.Registration = _viewModel.SelectedRunner.Registrations.FirstOrDefault()!;
        newSponsorship.Amount = _viewModel.Sum;
        DbHelper.Database.Sponsorships.Add(newSponsorship);

        new SponsorshipConfirmationWindow(_viewModel.SelectedRunner.EmailNavigation, _viewModel.Sum, _viewModel.SelectedCharity.CharityName).Show();
        Close();
    }
}